==> openshift-hive-operator-container-v2.3.6-4.tar.gz: openshift-hive-operator-container-v2.3.6-4/app/pkg/controller/hibernation/hibernation_actuator.go <==
package hibernation

//go:generate mockgen -source=./hibernation_actuator.go -destination=./mock/hibernation_actuator_generated.go -package=mock

import (
	log "github.com/sirupsen/logrus"

	"sigs.k8s.io/controller-runtime/pkg/client"

	hivev1 "github.com/openshift/hive/apis/hive/v1"
)

// HibernationActuator is the interface that the hibernation controller uses to
// interact with cloud providers.
type HibernationActuator interface {
	// CanHandle returns true if the actuator can handle a particular ClusterDeployment
	CanHandle(cd *hivev1.ClusterDeployment) bool
	// StopMachines will start machines belonging to the given ClusterDeployment
	StopMachines(cd *hivev1.ClusterDeployment, hiveClient client.Client, logger log.FieldLogger) error
	// StartMachines will select machines belonging to the given ClusterDeployment
	StartMachines(cd *hivev1.ClusterDeployment, hiveClient client.Client, logger log.FieldLogger) error
	// MachinesRunning will return true if the machines associated with the given
	// ClusterDeployment are in a running state. It also returns a list of machines that
	// are not running.
	MachinesRunning(cd *hivev1.ClusterDeployment, hiveClient client.Client, logger log.FieldLogger) (bool, []string, error)
	// MachinesStopped will return true if the machines associated with the given
	// ClusterDeployment are in a stopped state. it also returns a list of machines
	// that have not stopped.
	MachinesStopped(cd *hivev1.ClusterDeployment, hiveClient client.Client, logger log.FieldLogger) (bool, []string, error)
}

==> openshift-hive-operator-container-v2.4.4-3.tar.gz: openshift-hive-operator-container-v2.4.4-3/app/pkg/controller/hibernation/hibernation_actuator.go <==
package hibernation

//go:generate mockgen -source=./hibernation_actuator.go -destination=./mock/hibernation_actuator_generated.go -package=mock

import (
	log "github.com/sirupsen/logrus"

	"sigs.k8s.io/controller-runtime/pkg/client"

	hivev1 "github.com/openshift/hive/apis/hive/v1"
)

// HibernationActuator is the interface that the hibernation controller uses to
// interact with cloud providers.
type HibernationActuator interface {
	// CanHandle returns true if the actuator can handle a particular ClusterDeployment
	CanHandle(cd *hivev1.ClusterDeployment) bool
	// StopMachines will start machines belonging to the given ClusterDeployment
	StopMachines(cd *hivev1.ClusterDeployment, hiveClient client.Client, logger log.FieldLogger) error
	// StartMachines will select machines belonging to the given ClusterDeployment
	StartMachines(cd *hivev1.ClusterDeployment, hiveClient client.Client, logger log.FieldLogger) error
	// MachinesRunning will return true if the machines associated with the given
	// ClusterDeployment are in a running state. It also returns a list of machines that
	// are not running.
	MachinesRunning(cd *hivev1.ClusterDeployment, hiveClient client.Client, logger log.FieldLogger) (bool, []string, error)
	// MachinesStopped will return true if the machines associated with the given
	// ClusterDeployment are in a stopped state. it also returns a list of machines
	// that have not stopped.
	MachinesStopped(cd *hivev1.ClusterDeployment, hiveClient client.Client, logger log.FieldLogger) (bool, []string, error)
}

// HibernationPreemptibleMachines is the interface that the hibernation controller
// for preemptible instances on cloud providers.
type HibernationPreemptibleMachines interface {
	// ReplaceMachines uses the remote client to replace the preemptible machines
	// belonging to the given ClusterDeployment. Since it uses the remote client
	// it should only be called when the API is reachable.
	// replaced is true when at least one machine was replaced.
	ReplaceMachines(cd *hivev1.ClusterDeployment, remoteClient client.Client, logger log.FieldLogger) (replaced bool, err error)
}
